Histogramming
=============

.. toctree::
   :maxdepth: 1

   api/fix1d.rst
   api/fix1dmw.rst
   api/fix2d.rst
   api/var1d.rst
   api/var1dmw.rst
   api/var2d.rst
   api/histogram.rst
   api/histogram2d.rst
   api/bin_centers.rst
   api/bin_edges.rst

OpenMP Configuration
====================

.. toctree::
   :maxdepth: 1

   api/omp_conv.rst
   api/omp_cnd.rst
   api/config.rst
